@@ -33,6 +33,14 @@ protected:
     vec_basic symbols;
 
 public:
+    LambdaDoubleVisitor() = default;
+    LambdaDoubleVisitor(LambdaDoubleVisitor &&) = default;
+    LambdaDoubleVisitor &operator=(LambdaDoubleVisitor &&) = default;
+    // delete copy constructor:
+    // https://github.com/symengine/symengine/issues/1674
+    LambdaDoubleVisitor(const LambdaDoubleVisitor &) = delete;
+    LambdaDoubleVisitor &operator=(const LambdaDoubleVisitor &) = delete;
+
     void init(const vec_basic &x, const Basic &b, bool cse = false)
     {
         vec_basic outputs = {b.rcp_from_this()};
@@ -54,6 +62,7 @@ public:
             vec_pair replacements;
             // cse the outputs
             SymEngine::cse(replacements, reduced_exprs, outputs);
+            cse_intermediate_results.resize(replacements.size());
             for (auto &rep : replacements) {
                 auto res = apply(*(rep.second));
                 // Store the replacement symbol values in a dictionary for
@@ -64,7 +73,6 @@ public:
                 // Store it in a vector for faster use in call
                 cse_intermediate_fns.push_back(res);
             }
-            cse_intermediate_results.resize(cse_intermediate_fns.size());
             // Generate functions for all the reduced exprs and save it
             for (unsigned i = 0; i < outputs.size(); i++) {
                 results.push_back(apply(*reduced_exprs[i]));
@@ -112,8 +120,8 @@ public:
         auto it = cse_intermediate_fns_map.find(x.rcp_from_this());
         if (it != cse_intermediate_fns_map.end()) {
             auto index = it->second;
-            result_
-                = [=](const T *x) { return cse_intermediate_results[index]; };
+            T *cse_intermediate_result = &(cse_intermediate_results[index]);
+            result_ = [=](const T *x) { return *cse_intermediate_result; };
             return;
         }
         throw SymEngineException("Symbol not in the symbols vector.");
@@ -348,6 +356,11 @@ public:
     {
         throw NotImplementedError("Not Implemented");
     };
+
+    void bvisit(const UnevaluatedExpr &x)
+    {
+        apply(*x.get_arg());
+    };
 };
 
 class LambdaRealDoubleVisitor
@@ -428,7 +441,6 @@ public:
         }
 
         result_ = [=](const double *x) {
-
             bool result = bool(applys[0](x));
             for (unsigned int i = 0; i < applys.size(); i++) {
                 result = result && bool(applys[i](x));
@@ -445,7 +457,6 @@ public:
         }
 
         result_ = [=](const double *x) {
-
             bool result = bool(applys[0](x));
             for (unsigned int i = 0; i < applys.size(); i++) {
                 result = result || bool(applys[i](x));
@@ -462,7 +473,6 @@ public:
         }
 
         result_ = [=](const double *x) {
-
             bool result = bool(applys[0](x));
             for (unsigned int i = 0; i < applys.size(); i++) {
                 result = result != bool(applys[i](x));
@@ -485,7 +495,6 @@ public:
         }
 
         result_ = [=](const double *x) {
-
             double result = applys[0](x);
             for (unsigned int i = 0; i < applys.size(); i++) {
                 result = std::max(result, applys[i](x));
@@ -502,7 +511,6 @@ public:
         }
 
         result_ = [=](const double *x) {
-
             double result = applys[0](x);
             for (unsigned int i = 0; i < applys.size(); i++) {
                 result = std::min(result, applys[i](x));
@@ -657,5 +665,5 @@ public:
     }
 #endif
 };
-}
+} // namespace SymEngine
 #endif // SYMENGINE_LAMBDA_DOUBLE_H
